"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.App = void 0;
const http_request_1 = require("../../adapters/http-request");
const utils_1 = require("../../adapters/utils");
class App {
    url;
    headers;
    constructor(url, headers) {
        this.url = url;
        this.headers = headers;
    }
    /**
     * Get API usage by application for time frame specified.
     * @param applicationId ID of the application to get usage statistics.
     * @param queryString The optional querystrings that can be applied.
     * @param tokens The optional tokens that can be applied.
     * @returns API usage by application for time frame specified
     */
    GetApplicationApiUsage(applicationId, queryString, tokens) {
        const requestURL = (0, utils_1.formatQueryStrings)(`${this.url}/App/ApiUsage/${applicationId}/`, queryString);
        const authHeaders = (0, utils_1.parseAuthenticationHeaders)(this.headers, tokens);
        return (0, http_request_1.request)(requestURL, true, "GET", authHeaders);
    }
    /**
     * Get list of applications created by Bungie.
     * @returns List of applications created by Bungie.
     */
    GetBungieApplications() {
        const requestURL = `${this.url}/App/FirstParty/`;
        return (0, http_request_1.request)(requestURL, true, "GET", this.headers);
    }
}
exports.App = App;
