import { APIResponse } from "../../types/api";
import { CoreSettingsConfiguration, CoreSystem, GlobalAlert } from "../../types/interface";
export declare class Core {
    private url;
    private headers;
    constructor(url: string, headers: {
        [key: string]: string;
    });
    /**
     * List of available localization cultures
     * @returns List of available localization cultures
     */
    GetAvailableLocales(): Promise<APIResponse<{
        [key: string]: string;
    }>>;
    /**
     * Get the common settings used by the Bungie.Net environment.
     * @returns The common settings used by the Bungie.Net environment.
     */
    GetCommonSettings(): Promise<APIResponse<CoreSettingsConfiguration>>;
    /**
     * Get the user-specific system overrides that should be respected alongside common systems.
     * @returns The user-specific system overrides that should be respected alongside common systems.
     */
    GetUserSystemOverrides(): Promise<APIResponse<{
        [key: string]: CoreSystem;
    }>>;
    /**
     * Gets any active global alert for display in the forum banners, help pages, etc. Usually used for DOC alerts.
     * @returns Any active global alert for display in the forum banners, help pages, etc. Usually used for DOC alerts.
     */
    GetGlobalAlerts(queryString?: {
        includestreaming: boolean;
    }): Promise<APIResponse<GlobalAlert[]>>;
}
